Crate wasmworker_proc_macro

Crate wasmworker_proc_macro 

Procedural macros for exporting functions to WebWorkers.

This crate provides two macros:

Attribute Macros

webworker_channel_fn
A procedural macro that exports an async function with channel support for use with a WebWorker.
webworker_fn
A procedural macro that exports a simple function for use with a WebWorker.